package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@$!`0````````````(`*``!`````)P``#0```"<KP```@``!30`(``(
M`"@`'0`<``$``'`4JP``%"L!`!0K`0!X````>`````0````$````!@```#0`
M```T@```-(`````!`````0``!0````0````#````-`$``#2!```T@0``$P``
M`!,````$`````0````$``````````(````"```"0JP``D*L```4`````@```
M`0```)"K``"0JP$`D*L!`+`"``#D$@``!@````"````"````G*L``)RK`0"<
MJP$`0`$``$`!```&````!`````0```!(`0``2($``$B!``!$````1`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C,```0````0`````0```$=.50```````@````8````2````
M!````!0````#````1TY5`,I3/D)L_-HH#:<2PC#N)E>,^>=^80````4````@
M````"@```*`2``@"1A&@@```"%8`<1C""``\#0`5$0``$`(`*`````````!8
M(B`*!`H`1(0'J$`(16!)`(0!/D(\EP`!``@A4(`D"6`,@7A)1%HB0`!```$`
M0AD`0(",P(0``A"0$(,)``@!$)")0$#"28`L0)@`0``@`"`$"8"4@>R.EW;`
M!0`````````&````!P````D````*````````````````````"P````T````/
M````$0`````````2````%````!@`````````&@`````````;````'````!\`
M```@````)````"4````F````*``````````I````*@```"X`````````+P``
M`#`````Q````,@```#,`````````-0`````````Y````.@`````````^````
M```````````_````00```$(`````````0P```$0```!&````2@```$T`````
M````4````%$```!2````4P```````````````````%4`````````````````
M````````5P```%@`````````6@````````!<````7@```&````!A````8@``
M````````````8P```&<`````````:0````````!K`````````&X```!P````
M`````'(```!S````=````'8```!W````>@```%^6DQRC6N^05MN3',..A_\-
M.I<+1^PS.M)1!(2!=((->O!*:WU!CL5V5#R4S3\,K_<CSB#49-1\(72P`N!2
M=R@N3CWV9J_,9MOW`%X&I(?_`:\TZ+%(G>=39B&:X*<""LY*KO_/WD<MXT?&
M`6QSA<7L/Y`"Q@[@/3]^EGPU;T[>Q8D%D&"8[Q)G24DB`2/YI)V[DQQ\[1$/
MH))H9X;YG(%#1=7L6YH[#T%-G7QQA#"$+57KUJ?=HVM8[Y=YHP!EKPP4XIZB
M`O89VLWCG@4RI87[H6Q@,F+;[>K3[P[(.4`?N8WQ#NG[P\)*(GW_[=Z3'*U+
MX\#9<5@<*]#A(BP.L7,;G]:]8!;)65@[0!_:7TDAP^4_+)@BU&BZXY)\(?_D
M#HJ8W<)N>FGZB]DU5Y.M!&(WX_#!0_+OR-Z%($^;Z'P8WNLB%4]::,G%N9Q`
M,+B"#5$;?5^R`8MOO]I7&W9OXW"]T$M]:@E#UI\BQZ@A8F0'4ZD'D!T"$%%^
MJ9R;8M#Z@NPL]HMK?YI\T)\L_(?PEGSN"U'Y\]O3'>;_,**0=8(-0V9+$%Y?
M=F`%;++-%NI:\3VM.0TI_`VHH^#[2>)7Q!A7DEI2_=+O#RS?_DANQ=\??9`0
MZ2[%F[;(U;)QWZO*GP````````````````````#'!``````````````2````
M#```````````````(````!L``````````````"````#>!``````````````2
M````=@0``,2;````````$@```$<#``!TF@```````!(```#>`P``()H`````
M```2````P@,``/B:````````$@```(("```PK@$``````"``&`!%!@``.*X!
M``0````1`!@`=0(``'"8````````$@```+L#``"LFP```````!(```!E`@``
MG)D````````2````*08``'2L``!`````$@`-`"(%``!`K@$``````!``\?]U
M`P``6)L````````2````H`,``-B9````````$@```(8%``!0Q```V`,``!(`
M#0`3!```7)H````````2````K````#28````````$@```'T$``!\F```````
M`!(```#`!0``C+4``"@!```2``T`A@,``$2:````````$@```"L$```PF0``
M`````!(````Q!0``=+X!```````0`/'_2P$``!R;````````$@```/4$```4
M*P$``````!``\?^J!0``/+```-0````2``T`W@4``/"9````````$@```%0&
M``"LNP``I`@``!(`#0!I!0``K)P``$0````2``T```0``"B;````````$@``
M`#X"``!DFP```````!(```"M`P``<)L````````2````<`,``-";````````
M$@```'L!``"XF````````!(```"0!```0*X!``0````A`!D`+P,```B:````
M````$@```!T$``!0F@```````!(````V`P``W)L````````2````T`,``,R9
M````````$@```+4#``!8F````````!(```"(`0``H)@````````2````FP``
M`*B9````````$@````\%``!`K@$``````!``\?\I`P``+)H````````2````
M3P,``%29````````$@```!@!```TFP```````!(```#Y`0``[)H````````2
M````D00``$"N`0`$````(0`9`#P%``!TO@$``````!``\?_G````L)H`````
M```2````=@4``.3(```$````$@`-`!<"``#<F````````!(````9!@``Z,@`
M`&@````2``T`20(``#B:````````$@```&$&``#XL@``"`$``!(`#0"&`@``
M`)P````````2``T`@`4``#3.````````$@`.`(\#``",F@```````!(````3
M!@``%)@````````2``L`T@```.":````````$@```/(#```,F0```````!(`
M``#)`P``F)H````````2`````@8``#S.```$````$0`/`!8%``!`K@$`````
M`!``\?]/!```0)L````````2````+P```)"9````````$@```&<$``#(F@``
M`````!(```#S!0``/*X!``0````1`!@`6`$``+29````````$@````,%``",
M*P$``````!``\?\1!@``*,@``#0````2``T`G`$``$R8````````$@````H%
M``!TO@$``````!``\?]S!@``F+D``!0"```2``T`^````-"8````````$@``
M`%X#``#4F@```````!(```!S````Z)L````````2````%0,``&"9````````
M$@```%<"```4F@```````!(````&`0``])L````````2````/`$``/R9````
M````$@```%X```"@FP```````!(```#E`0``))D````````2````/0```+R:
M````````$@```(\$``!`K@$`!````!$`&0#7`P``Z)@````````2````Q0$`
M`/28````````$@```)P%``#,J@``5````!(`#0`P!0``=+X!```````0`/'_
M"P0``&28````````$@```,,```#`F0```````!(```"``@``,*X!```````0
M`!@`600``$R;````````$@```*<$``!(K@$`!````!$`&0!I`0``K)@`````
M```2````B@```+B;````````$@```,P%``!TM0``&````!(`#0"@`@``&)D`
M```````2````C0(```2;````````$@```(H$``!`MP``6`(``!(`#0`[!```
M`)D````````2````H0$``$B9````````$@```#($```0FP```````!(```"K
M`@``3*X!`!,````1`!D`2@8``'C1``!N60``$0`/`.L#``#DF0```````!(`
M``#E`P``I)H````````2````*@$``'B9````````$@```'T#``"4FP``````
M`!(```!O!```;)D````````2````F0(``(":````````$@```-,!``"(FP``
M`````!(```"`!@```+0``'0!```2``T`0@0``(29````````$@```*8!``!H
MF@```````!(```"G`P``0)@````````2````)P(``,28````````$@```.<%
M``"TM@``C````!(`#0!/````?)L````````2````6`4``!"Q```$````$@`-
M`+(!``"(F````````!(````P`@``/)D````````2`````&QI8G!E<FPN<V\`
M7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T
M97)M`%!E<FQ?27-T871B=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X
M:71?9FQA9W-?<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M
M<&-V7W!T<@!097)L7V%T9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P
M='(`<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])
M<&%R<V5R7W!T<@!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E
M<FQ?271O<%]E;G9?<'1R`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T
M<'9N`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V
M86Q?<'1R`%!E<FQ?26]P7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?
M9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S
M971P=@!097)L7T=T:')?:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E
M<FQ?27!E<FQ?9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P
M97)L7W)U;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%]?
M9&%T85]S=&%R=`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M
M96UO<GE?=W)A<`!L:6)R97-O;'8N<V\N,@!L:6)N<VPN<V\N,0!L:6)D;"YS
M;RXR`&QI8FTN<V\N-@!L:6)C<GEP="YS;RXQ`&QI8G5T:6PN<V\N,0!L:6)P
M=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`
M7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`')E860`;&EB8RYS;RXV`%]?<F5G
M:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?
M7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE
M;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER
M`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS
M=&%T-C0`7U]C='EP95]B7VQO8P!G971U:60`<F5A9&QI;FL`97AE8W9P`%]?
M;65M8W!Y7V-H:P!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C
M8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QD+6QI
M;G5X+G-O+C,`7U]S=&%C:U]C:&M?9W5A<F0`;&EB9V-C7W,N<V\N,0!?7V%E
M86)I7W5N=VEN9%]C<'!?<'(P`%]?865A8FE?=6YW:6YD7V-P<%]P<C$`7U]E
M>&ED>%]S=&%R=`!?7V5X:61X7V5N9`!?961A=&$`7U]B<W-?<W1A<G0`7U]B
M<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?`"]U<W(O;&EB+W!E<FPU
M+T-/4D4`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S
M=5]F:6YI`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A
M<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?=7-E<FYA;65?
M9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!S:7IE7VQO861?;65?,@!?24]?
M<W1D:6Y?=7-E9`!X<U]I;FET`%]?;&EB8U]C<W5?:6YI=`!84U]);G1E<FYA
M;'-?4$%27T-,14%24U1!0TL`;F%M95]L;V%D7VUE7S(`<&%R7VUK=&UP9&ER
M`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P87)?:6YI=%]E;G8`
M1TQ)0D-?,BXT`$=#0U\S+C4``````P```````P`"``0``@`"``$``0````(`
M```!``$``@`"``$``@````(``0`"``(``0````$``0`"``$``0`"`````@`"
M`````@`$``(`!``"``(```````$`!``$```````"``$````!`````0````$`
M`0`!``(``0````(``@`!``$``@````(``0````$``0````$``0````(````$
M``````````````````(``@````$``0`"`````0`"``4```````$```````$`
M`@`"``(````!``(``@````(``@`"`````0`"`````@````$````!````````
M``$``0"9!```$````"`````4:6D-```%`(T&`````````0`!``4#```0````
M(````!1I:0T```0`C08````````!``$`N00``!`````@````529Y"P```P"7
M!@````````$``0!4`P``$``````````4:6D-```"`(T&````````+*X!`!4"
M``!`K@$`%%<``$BN`0`48```3*X!`!1J``#HK`$`%A0``.RL`0`6=@``\*P!
M`!9*``#TK`$`%BH``/BL`0`67```_*P!`!8+````K0$`%A4```2M`0`6>P``
M"*T!`!8"```,K0$`%BL``!"M`0`680``%*T!`!8D```8K0$`%G<``!RM`0`6
M30``(*T!`!8V```DK0$`%E@``"BM`0`660``+*T!`!9G```PK0$`%C\``#2M
M`0`69```.*T!`!95```\K0$`%A@``$"M`0`6?```1*T!`!9H``!(K0$`%B\`
M`$RM`0`64```4*T!`!9P``!4K0$`%FX``%BM`0`6=```7*T!`!9$``!@K0$`
M%@T``&2M`0`6+```:*T!`!9'``!LK0$`%ET``'"M`0`6*0``=*T!`!81``!X
MK0$`%FP``'RM`0`6'0``@*T!`!93``"$K0$`%B8``(BM`0`640``C*T!`!8'
M``"0K0$`%BX``)2M`0`6.```F*T!`!87``"<K0$`%B<``*"M`0`6$P``I*T!
M`!9U``"HK0$`%@8``*RM`0`6<0``L*T!`!8\``"TK0$`%D```+BM`0`6;0``
MO*T!`!8T``#`K0$`%E8``,2M`0`610``R*T!`!9.``#,K0$`%CX``-"M`0`6
M,0``U*T!`!8(``#8K0$`%F4``-RM`0`6:0``X*T!`!8:``#DK0$`%B```.BM
M`0`6,```[*T!`!9#``#PK0$`%E\``/2M`0`6$```^*T!`!8A``#\K0$`%B(`
M``"N`0`6>0``!*X!`!9R```(K@$`%F\```RN`0`65```$*X!`!8,```4K@$`
M%F(``!BN`0`6!0``'*X!`!8C```@K@$`%B@``"2N`0`63P``**X!`!92```0
M0"WI!P$`ZQ"`O>@$X"WE!."?Y0[@C^`(\+[EK!0!``#&C^(1RHSBK/2\Y0#&
MC^(1RHSBI/2\Y0#&C^(1RHSBG/2\Y0#&C^(1RHSBE/2\Y0#&C^(1RHSBC/2\
MY0#&C^(1RHSBA/2\Y0#&C^(1RHSB?/2\Y0#&C^(1RHSB=/2\Y0#&C^(1RHSB
M;/2\Y0#&C^(1RHSB9/2\Y0#&C^(1RHSB7/2\Y0#&C^(1RHSB5/2\Y0#&C^(1
MRHSB3/2\Y0#&C^(1RHSB1/2\Y0#&C^(1RHSB//2\Y0#&C^(1RHSB-/2\Y0#&
MC^(1RHSB+/2\Y0#&C^(1RHSB)/2\Y0#&C^(1RHSB'/2\Y0#&C^(1RHSB%/2\
MY0#&C^(1RHSB#/2\Y0#&C^(1RHSB!/2\Y0#&C^(1RHSB_/.\Y0#&C^(1RHSB
M]/.\Y0#&C^(1RHSB[/.\Y0#&C^(1RHSBY/.\Y0#&C^(1RHSBW/.\Y0#&C^(1
MRHSBU/.\Y0#&C^(1RHSBS/.\Y0#&C^(1RHSBQ/.\Y0#&C^(1RHSBO/.\Y0#&
MC^(1RHSBM/.\Y0#&C^(1RHSBK/.\Y0#&C^(1RHSBI/.\Y0#&C^(1RHSBG/.\
MY0#&C^(1RHSBE/.\Y0#&C^(1RHSBC/.\Y0#&C^(1RHSBA/.\Y0#&C^(1RHSB
M?/.\Y0#&C^(1RHSB=/.\Y0#&C^(1RHSB;/.\Y0#&C^(1RHSB9/.\Y0#&C^(1
MRHSB7/.\Y0#&C^(1RHSB5/.\Y0#&C^(1RHSB3/.\Y0#&C^(1RHSB1/.\Y0#&
MC^(1RHSB//.\Y0#&C^(1RHSB-/.\Y0#&C^(1RHSB+/.\Y0#&C^(1RHSB)/.\
MY0#&C^(1RHSB'/.\Y0#&C^(1RHSB%/.\Y0#&C^(1RHSB#/.\Y0#&C^(1RHSB
M!/.\Y0#&C^(1RHSB_/*\Y0#&C^(1RHSB]/*\Y0#&C^(1RHSB[/*\Y0#&C^(1
MRHSBY/*\Y0#&C^(1RHSBW/*\Y0#&C^(1RHSBU/*\Y0#&C^(1RHSBS/*\Y0#&
MC^(1RHSBQ/*\Y0#&C^(1RHSBO/*\Y0#&C^(1RHSBM/*\Y0#&C^(1RHSBK/*\
MY0#&C^(1RHSBI/*\Y0#&C^(1RHSBG/*\Y0#&C^(1RHSBE/*\Y0#&C^(1RHSB
MC/*\Y0#&C^(1RHSBA/*\Y0#&C^(1RHSB?/*\Y0#&C^(1RHSB=/*\Y0#&C^(1
MRHSB;/*\Y0#&C^(1RHSB9/*\Y0#&C^(1RHSB7/*\Y0#&C^(1RHSB5/*\Y0#&
MC^(1RHSB3/*\Y0#&C^(1RHSB1/*\Y0#&C^(1RHSB//*\Y0#&C^(1RHSB-/*\
MY0#&C^(1RHSB+/*\Y0"PH.,`X*#C!!"=Y`T@H.$$("WE!``MY1#`G^4$P"WE
M#`"?Y0PPG^43___K"?__Z^3(``!`MP``Z,@``!0PG^44()_E`S"/X`(@D^<`
M`%+C'O\O`0[__^J0$`$`4`$``!`PG^4`(-/E``!2XP$@H`,`(,,%'O\OX5^N
M`0`@`)_E$$`MZ0`PD.4``%/C$("]"!`PG^4``%/C$("]"#/_+^$0@+WHF*L!
M````````,-#E``!3XP`0H`$)```*`!"@X0$@@.(@`)_E``"0Y0``T.4``%/A
M`A"@`0$PTN0``%/C^O__&@$`H.$>_R_A1,X``/`/+>D%W4WB'%"`X@`@H.,-
M,*#A`A"5YP%,H.$!Q*#A(4R$X?_(#.(A%*#A#,"$X?\<`>(!$(SA`A"#YP0@
M@N)``%+C\O__&DU/@^(T,(/B%!`3Y0`@D^4LP!/E`B`AX#00$^4,("+@`2`B
MX.(OH.$,((/E!#"#X@0`4^'S__\:$!"0Y0`@G>4@!)#I#("0Y63,G^4$<)WE
M`#"0Y0(@@>`'<(C@#!"@X06`R.$,P(+@!2`*X&5!H.'CS8S@`B"(X0$0A^`(
M<)WE`B",X`-@RN$#4`3@(,R?Y050AN$'<(K@!1"!X`Q@H.$,P(?@#'"=Y>(=
M@>!B4:#A8X&@X0*0Q.$!H,CA!F"'X`@@`N`%<`'@!$"&X`=PBN'AS8S@`B")
MX0(@C.#0JY_E!\"$X!!`G>5A<:#A%!"=Y>+-C.`*8*#A"J"$X&)!H.$&8('@
M"("*X`00#.`,H,?A`I#%X0$0BN$%4(;@!R`"X.R-B.`"((GAA*N?Y0$0A>`8
M4)WE`B"(X&R!H.$<P)WEXAV!X`I@H.$*H(7@8E&@X09@C.`'<(K@!<`!X`&@
MR.$"D,3A#,"*X01`AN`((`+@X7V'X`(@B>$TJY_E#,"$X"!`G>4"((?@87&@
MX200G>7BS8S@"F"@X0J@A.!B0:#A!F"!X`B`BN`$$`S@#*#'X0*0Q>$!$(KA
M!5"&X`<@`N#LC8C@`B")X>2JG^4!$(7@*%"=Y0(@B.!L@:#A+,"=Y>(=@>`*
M8*#A"J"%X&)1H.$&8(S@!W"*X`7``>`!H,CA`I#$X0S`BN$$0(;@""`"X.%]
MA^`"((GAE*J?Y0S`A.`P0)WE`B"'X&%QH.$T$)WEXLV,X`I@H.$*H(3@8D&@
MX0*0Q>$&8('@"("*X`00#.`,H,?A!R`"X`50AN#LC8C@.&"=Y0(@B>$!$(KA
M0*J?Y0(@B.`!$(7@;(&@X3S`G>7B'8'@"E"@X0J@AN!B8:#A!5",X`=PBN`&
MP`'@`:#(X0*0Q.$,P(KA!$"%X`@@`N#\J9_E#,"$X$!`G>7A?8?@`B")X0(@
MA^`*<*#A"J"$X&%!H.%$$)WEXLV,X&)1H.$"D,;A!W"!X`B`BN`%$`S@#*#$
MX00@`N`"((GA!F"'X`$0BN'LC8C@`J"(X*"YG^4!((;@2!"=Y6S!H.$+8*#A
M"["!X.HM@N!J$:#A"I#%X02PB^`,H`K@3$"=Y0*`S.$!<`+@"J")X6*1H.'B
M+8O@"J""X`9@A.!0()WE5$F?Y050AN`$0(+@`6`IX`=PB.$,P(3@"B`FX`=0
MA>`TN9_E`B",X%3`G>7JC87@:E&@X0M@H.$+L(S@"<`EX&AQH.'H+8+@"(`L
MX%C`G>4%H"?@!F",X`E@AN`"0"K@`1"+X`1`AN#LR)_E7&"=Y0B`@>!B$:#A
M!Z`AX.(MB.`,P(;@XDV$X`5@C.!BP:#A`B`JX,"(G^4"((;@8&"=Y0&@+.`(
M4*#A"("&X.0M@N!D8:#A!W"(X`2`*N!D0)WE#*`FX`APA^`%4(3@:("=Y81(
MG^4"H"K@`5"%X&(1H.$$0(C@XBV'X`I0A>`&H"'@XEV%X`QPA.!BP:#A`B`J
MX%2(G^4"((?@;'"=Y0&@+.`(0*#A"("'X.4M@N!E<:#A!F"(X`6`*N!P4)WE
M#*`GX`A@AN`$0(7@=("=Y1A8G^4"H"K@`4"$X&(1H.$%4(C@XBV&X`I`A.`'
MH"'@XDV$X`Q@A>!BP:#A`B`JX.B'G^4"((;@>&"=Y0A0H.$(@(;@!W"(X'R`
MG>4!H"S@9&&@X050B.`$@"K@Y"V"X`R@)N`(<(?@L$>?Y8"`G>4"H"K@`5"%
MX&(1H.$$0(C@XBV'X`I0A>`&H"'@XEV%X`QPA.!BP:#A`B`JX'R'G^4"((?@
MA'"=Y0A`H.$(@(?@!F"(X(B`G>4!H"S@97&@X01`B.`%@"K@Y2V"X`R@)^`(
M8(;@1%>?Y8R`G>4"H"K@`4"$X&(1H.$*0(3@XBV&X`50B.`'8"'@XDV$X`Q0
MA>!BP:#A`B`FX!"'G^4"((7@D%"=Y0A@H.$(@(7@!W"(X)2`G>4!H"S@9%&@
MX09@B.`$@"K@Y"V"X`R@)>`(<(?@V$:?Y9B`G>4"H"K@`1"&X&)AH.$$0(C@
MXBV'X`6`)N`*$('@XAV!X`S`A.!B0:#A`B`HX`(@C."@=I_EG,"=Y0:@).`'
M<(S@X2V"X&'!H.$%4(?@`1`JX`%0A>"`AI_EH!"=Y020C.'B787@"("!X`*0
M">!B$:#A9':?Y:0@G>4$H`S@#+"!X09@B.`'<(+@"H")X06P"^`,D`'@!$"'
MX`F@B^%E(:#A"("&X`J@A.`L9I_EJ$"=Y>5=B.`!<(+A!;`'X`&0`N`&8(3@
M#,"&X`F`B^%E0:#A"(",X`!VG^6LP)WEY5V*X`)@A.$%L`;@`I`$X`=PC.`!
M$(?@":"+X67!H.$*H('@U&6?Y;`0G>7E78C@!'",X06P!^`$D`S@!F"!X`(@
MAN`)@(OA91&@X0B`@N"H=9_EM""=Y>5=BN`,8('A!;`&X`R0`>`'<(+@!$"'
MX`F@B^%E(:#A"J"$X'QEG^6X0)WEY5V(X`%P@N$%L`?@`9`"X`9@A.`,P(;@
M"8"+X65!H.$(@(S@4'6?Y;S`G>7E78K@`F"$X06P!N`"D`3@!W",X`$0A^`)
MH(OA9<&@X0J@@>`D99_EP!"=Y>5=B.`$<(SA!;`'X`20#.`&8('@`B"&X`F`
MB^%E$:#A"(""X/ATG^7$()WEY5V*X`Q@@>$%L`;@#)`!X`=P@N`$0(?@":"+
MX64AH.$*H(3@S&2?Y<A`G>7E78C@`7""X06P!^`!D`+@!F"$X`S`AN`)@(OA
M94&@X0B`C."@=)_ES,"=Y>5=BN`"8(3A!;`&X`*0!.`'<(S@`1"'X`F@B^%E
MP:#A"J"!X'1DG^70$)WEY5V(X`1PC.$%L`?@!)`,X`9@@>`"((;@"8"+X641
MH.$(@(+@2'2?Y=0@G>7E78K@#&"!X06P!N`,D`'@!W""X`1`A^`)H(OA92&@
MX0J@A.`<9)_EV$"=Y>5=B.`!<(+A!;`'X`&0`N`&8(3@#,"&X`F`B^%E0:#A
M"(",X/!SG^7<P)WEY5V*X`)@A.$%D`;@`J`$X`=PC.`!$(?@"G")X67!H.$'
M<('@Q&.?Y>`0G>7E78C@!(",X060".`$H`S@!F"!X`(@AN`*8(GA91&@X09@
M@N"8@Y_EY""=Y>5=A^`,<('A!9`'X`R@`>`(@(+@!$"(X`J`B>%E(:#A"("$
MX&QSG^7H0)WEY6V&X`%0@N$!H`+@!I`%X`=PA.`,<(?@"I")X69!H.'FS8C@
M0%.?Y0E@A^#L<)WE`J"$X050A^`,H`K@`H`$X`$0A>`(@(KA('.?Y0B`@>#P
M$)WE[&V&X`>@H.%LP:#A!W"!X/00G>5F4:#A!)`LX.:-B.`*H('@!F`IX`RP
M)>`"((?@!B""X`1`BN#X8)WE"+`KX-1RG^5H$:#A"T"$X.B-@N#HG83@!W"&
MX/Q`G>6X8I_E!:`AX`S`A^`&<*#A!F"$X&@AH.$%4(;@"(`JX`!AG>5I0:#A
M",",X.G-C.`'<(;@`F`DX`&`(N`,8";@`7"'X`F`*.`&<(?@;**?Y01AG>5L
M$:#A"%"%X.S-A>`*H(;@!%`AX.Q]A^`"H(K@2&*?Y6PAH.$,P"7@"%&=Y0:`
MH.$&8(7@!$"&X`QAG>5G4:#A#,"*X`&0(N#GS8S@"("&X`)@)>`'<"G@`8"(
MX`Q@)N`'0(3@`**?Y09PB.`089WE;!&@X0J@AN#LS83@!4`AX.Q]A^`"H(K@
MW&&?Y6PAH.$,P"3@%$&=Y0:`H.$&8(3@!5"&X!AAG>5G0:#A#,"*X`&0(N#G
MS8S@"("&X`)@).`'<"G@`8"(X`Q@)N`'4(7@E*&?Y09PB.`<89WE;!&@X0J@
MAN#LS87@!%`AX.Q]A^`"H(K@<&&?Y6PAH.$,P"7@(%&=Y0:`H.$&8(7@!$"&
MX"1AG>5G4:#A#,"*X`&0(N#GS8S@"("&X`)@)>`'<"G@`8"(X`Q@)N`'0(3@
M**&?Y09PB.`H89WE;!&@X0J@AN#LS83@!4`AX.Q]A^`"H(K@!&&?Y6PAH.$,
MP"3@+$&=Y0:`H.$&8(3@!5"&X#!AG>5G0:#A`9`BX`S`BN#GS8S@`J`DX`B`
MAN`'<"G@!U"%X`&`B.`,<"K@!W"(X+A@G^4T@9WE;!&@X09@B.#LS87@!(`A
MX`R`*.`"8(;@F%"?Y0A@AN`X@9WE['V'X&PAH.$%P*#A!5"(X#R!G>4!H"+@
M"#"#X&>!H.'G;8;@#,"#X`1`A>`","C@!W`JX`8P(^`'0(3@`1",X`,0@>#F
M/83@,`"0Z0/`A.`,H)#E$$"0Y69AA>`(@(K@`B"$X.,]@>``,(#E$""`Y03`
M@.4(8(#E#("`Y07=C>+P#[WH'O\OX9EY@EJAZ]ENW+P;C];!8LKP1RWI`'!0
MX@&@H.$!```:``"@X_"'O>B4,)_E`("3Y0``6./Y__\*`&#7Y3T`5N,``%83
M`&"@`P%@H!,%```*!V"@X0$P]N4]`%/C``!3$_O__QH&8&?@`$"8Y0``5./J
M__\*"%"@X0(``.H$0+7E``!4X^7__PH$`*#A!Q"@X08@H.$T_/_K``!0X_;_
M_QH&,-3G/0!3X_/__QH%4&C@15&@X0$`AN(`4(KE``"$X/"'O>A`K@$`!.`M
MY0S03>($$(WBS?__ZPS0C>(`@+WH$$`MZ4!`G^4``)3E`0!PXQ"`O1@T`)_E
M\O__ZP``4.,&```*``#0Y0``4.,#```*,`!0X@$`H!,``(3E$("]Z```H.,`
M`(3E$("]Z#2N`0"\S@``<$`MZ0C03>(`4*#A!$"-XCA@G^4&``#J`#"6Y00@
MG>4",8/@!""SY00@`^4``%+C^___&@4`H.$$$*#AIO__ZP``4./S__\:"-"-
MXG"`O>A`K@$`\$$MZ0':3>((T$WBX$"?Y0A0C>($4$7B`#"4Y0'*C>(!<*#A
M`H"@X<@`G^4%$*#AQ""?Y00PC.77^__K`&!0XB(``-H!,$;B`R#5YP``4N,5
M```*!0"@X2\0H.,&(*#A]/O_ZP``4.,8```*``"@X^?[_^L``)#E6_O_ZP<0
MH.$%(*#A!C"@X7[[_^L!.HWB!""3Y0`PE.4#`%+A$P``&@C0C>(!VHWB\(&]
MZ```4^,&```*`V"@X04`H.$O$*#C!B"@X=O[_^L``%#CYO__&@``H./.^__K
M``"0Y4+[_^L'$*#A"""@X23[_^OF___JB/O_ZTBN`0#(S@``_P\``!!`+>D`
M`*#CP?O_ZP``D.4U^__K`!#@XRK[_^L``*#CN_O_ZP``D.4O^__K`""@XP00
MG^400+WHS?O_ZK2L```00"WI``"@X['[_^L``)#E)?O_Z]GZ_^L`,)#E``"@
MXP1`D^6J^__K``"0Y1[[_^OP^O_K`##0Y1@PQ.4``*#CH_O_ZP``D.47^__K
MR_K_ZP`PD.4``*#C!$"3Y9S[_^L``)#E$/O_Z^7Z_^L`,)#E``"@X[`QT^'^
M/,/CNC'$X9/[_^L``)#E!_O_Z[OZ_^L`,)#E``"@XP1`D^6,^__K``"0Y0#[
M_^L<$9_E`""@XVS[_^L<`(3E``"@XX3[_^L``)#E^/K_ZZSZ_^L`,)#E``"@
MXP1`D^5]^__K``"0Y?'Z_^O`^O_K`#"0Y2`PA.4``*#C=OO_ZP``D.7J^O_K
MGOK_ZP`PD.4``*#C!$"3Y6_[_^L``)#EX_K_ZS;[_^L`,)#E``!3XP8```H`
M`*#C9_O_ZP``D.7;^O_K+OO_ZP`PD.5L,)/E)#"$Y0``H.-?^__K`$"@XP``
MD.72^O_KAOK_ZP`PD.4$`*#A!#"3Y2A`@^56^__K``"0Y<KZ_^M^^O_K`#"0
MY00`H.$$,)/E+$"#Y4[[_^L``)#EPOK_ZW;Z_^L`,)#E!`"@X01`D^5'^__K
M``"0Y;OZ_^LO^__K`#"0Y3`PA.40@+WHT,\``/!!+>D`4%#B<-!-X@(```H`
M,-7E``!3XP$``!IPT(WB\(&]Z&WZ_^L`8%#B"("-$OG__PH&`*#A'_O_ZP!`
M4.(%`*#A)```"A,PU.430(3B+@!3XR4```JZ^O_K`'"@X00`H.&W^O_K``"'
MX`(`@.+A^O_KH#"?Y0$0H.,`(.#C!$"-Y0!0C>4`<*#A#?O_ZP<0H.$((*#A
M`P"@X\WZ_^L!`'#C!P"@X0,```H8,)WE#SH#X@$)4^,5```*I/K_ZP<`H.%^
M^O_K!@"@X?KZ_^L`0%#B!0"@X=K__QH&`*#AMOK_ZP4`H.',^O_KRO__Z@$P
MU.4``%/CS?__"BX`4^/4__\:`C#4Y0``4^/(__\*T/__ZKG__^OH___JV,X`
M`'!`+>D`0*#A``"@X_3Z_^L``)#E:/K_Z[[Z_^L$$*#A`""@X0,`H./5^O_K
M`%!0X@$```H``*#C<("]Z.CZ_^L``)#E7/K_Z[+Z_^L0,)#E#SH#X@$)4^,(
M```*!0"@X=_Z_^L``)#E4_K_ZZGZ_^L0,)#E#SH#X@H*4^/L__\:!`"@X0(0
MH.-.^O_K`0!PX@``H#-P@+WH\$`MZ;A0G^4"VDWB'-!-X@`PE>4"*HWB%#""
MY:;Z_^L!2HWB&$"$X@A`1.*4P)_E`1"@XY`@G^60,)_E`1"-Z`0`H.&Q^O_K
M``!0XPD``*H`0*#C`CJ-XA0@D^4`,)7E!`"@X0,`4N$4```:'-"-X@+:C>+P
M@+WH&&"-X@Q@1N($`*#A!A"@X0$JH..0^O_K`'!0XNW__[H!`(?B:/K_ZP!`
M4.+J__\*!A"@X0<@H.$\^O_K`#"@XP<PQ.?D___J8OK_ZTBN`0#LS@```1``
M`.#.``#)___J\$<MZ0`PT>4!0*#A/0!3XP%`@0((T$WB`&"@X00`H.$D^O_K
M!!"-X@!PH.$&`*#A+/[_ZP!04.(+```*'?K_ZP``5^$`,*"37P``B@,@U.<#
M(,7G``!2XP$P@^+Z__\:``"@XPC0C>+PA[WH:(&?Y0``F.4`,)#E``!3XP-0
MH`$($*`#!0``"@%0A>(%,9#G``!3X_O__QH"$(7B`1&@X3@QG^4`()/E``!2
MXP<```II^O_K``!0XP"@H.$``(CE!9&@$0P``!H``.#CY/__Z@$@H.,!`*#A
M`""#Y2+Z_^L`H%#B]___"@61H.$`$)CE"2"@X2[Z_^L`H(CE`3"%X@`@H.,#
M(8KG!%"-Y0`PUN4]`%/C``!3$P`PH`,!,*`3`R"@`04```H&(*#A`3#RY3T`
M4^,``%,3^___&@(@9N`"`(?B`@"`X`!0F.4&^O_K``!0XPD`A>?:__\*>#"?
MY000G>4`()/E`##6Y0$ADN<``%/C`##"Y0D```H]`%/C`P``&@8``.H]`%/C
M`6"&X@,```H!,-;E`3#BY0``4^/X__\:/0"@XP(0H.$`,*#C``#"Y0,@U.<!
M(.'E``!2XP$P@^+Z__\:I/__Z@20G>4$@)_E"9&@X<O__^I`K@$`8*X!`/C`
MG^7P1RWI!$",XBC03>(`<*#A#P"TZ!!0C>(%8*#A#P"FZ`,`E.@00)WE`P"&
MZ``PU.4``%/C%P``"AR@G.4&``#JM_G_ZP``4.,4```*!$"UY0`PU.4``%/C
M#@``"@0`H.'4_?_K!Q"@X0!@4.("```*`##6Y0``4^/P__\:!`"@X0<0H.%C
M___K!$"UY0`PU.4``%/C\/__&BC0C>+PA[WH!P"@X8GY_^L`D*#A"@"@X8;Y
M_^L`@*#A!@"@X8/Y_^L(@(G@`H"(X@``B."L^?_K`1"@XP`@X.,@,)_E"&"-
MY8`$C>@`@*#AV/G_ZP0`H.$($*#A1___Z]/__^I$S@``\,X``"3!G^5P0"WI
M#P"\Z"C03>(-X*#A#P"NZ!!1G^4/`+SH`&"5Y21@C>4/`*[HL,#<X;#`SN'X
M`)_EN/W_Z_0`G^6V_?_K\`"?Y;3]_^OL`)_ELOW_Z^@`G^6P_?_KY`"?Y:[]
M_^O@`)_EK/W_Z]P`G^6J_?_KV`"?Y:C]_^O4`)_EB_W_ZPU`H.$`$%#B`0``
M"JP`G^4>___KO`"?Y83]_^L`$%#B`0``"K``G^48___KK`"?Y7[]_^L`$%#B
M"@``"G0`G^42___K9`"?Y900G^4/___K)""=Y0`PE>4#`%+A$```&BC0C>)P
M@+WH>`"?Y6_]_^L`$%#B`@``"CP`G^4#___K[___ZA$`A.)<$)_E"B"@XX_Y
M_^L``%#CZ?__&AL0A.+T___J5_G_ZV3.``!(K@$`^,X```C/```4SP``O,X`
M`"#/```LSP``.,\``$C/``!4SP``8,\``'3/``"(SP``E,\``,3/``"DSP``
MN,\``!!`+>GL^/_K&_G_ZP``4.,``)`5$("]Z!!`+>D`0%#B'@``"@`PU.4`
M`%/C&P``"@CY_^L!`$#B`""$X`(`5.'LP)\E#```*N3`G^4``-3G`#"<Y0`0
MT^4!`%#A`P``"AD``.H`,-+E``!3X18``!H!($+B`@!4X?G__SH$`%+A%@``
M&@``G.4`(-+E`##0Y0,`4N$!```*$$"]Z%_Y_^H"`*#C&/G_ZP`P4.(>```*
M`B"@XWP0G^400+WHZ_C_Z@`PTN4!`%/AZ___"@$@0N("`%3A^?__.@0`4N'H
M__\*``"<Y0$@0N("`%3A`P``*@`0TN4`,-#E`P!1X?C__PH"(&3@`C""X@$*
M4^,`,*"#!0``B@$ZH.,$$*#A`2""XA0`G^6;^/_K##"?Y0,`H.$0@+WH1,X`
M`,C/``!DK@$`<$`MZ0!0H.&R___K`##0Y0``4^,`0*`!"0``"F`@G^4`0*#A
M`""2Y0$`@.(`(-+E`@!3X0!`H`$!,-#D``!3X_K__QKS_/_K``!0XW"`O0@`
M`%7C<("]"``PU>4``%/C<("]"`0`H.$8$)_EOOC_ZP``5.%P@+T8!0"@X7!`
MO>C2_?_J1,X``,S/``!P0"WI&-!-XA0`C>40$(WE#""-Y10`C>(0$(WB#""-
MX@7Y_^OX$9_E^`&?Y0$@H.%0!`#K``"@XVGX_^L`0-#E``!4XPL``!IB^/_K
MV"&?Y0``4./T#P+E;P``"H?X_^L$`*#A]_C_ZP``D.5K^/_KS?C_ZP!`P.4`
M`*#C\?C_ZP``D.5E^/_K]/C_ZP`@T.4`,*#A`B""XP`@P^4``*#CZ/C_ZP``
MD.5<^/_KZ_C_ZP`PT.4!,(/C`##`Y11`G>4%0(3B!`"@X?X$`.L`(*#C`#"@
MXU`$`.M0(9_E4#&?Y7X%`.L``%#C2```&@0!H.&S^/_K,$&?Y13@G>4!`%[C
M`,"@X1``G>7PSP3E`#"0Y0`PC.4<,9_E!#",Y1@QG^4(,(SE%#&?Y0PPC.4$
M,*#C[#\$Y0<``-H,(*#A`3"@XP,1D.<!,(/B`P!>X1`0@N4$((+B^?__R@/@
MCN+T#Q3E`%"@XPX@H.$,,*#AT!"?Y0!0C>4.48SG[/?_ZP!04.(,```*]`\4
MY5KX_^NT`)_E=_S_ZY!@G^4``%#C$```"O0/%.78]__K*/C_ZP4`H.$8T(WB
M<("]Z&PPG^5H8)_E]`\3Y>[W_^L`4*#A]`\4Y4CX_^ML`)_E9?S_ZP``4./N
M__\:Z`\6Y0``4.,!```*7___Z^G__^I,`)_E7/S_ZP``4./H#P;EY/__"O?_
M_^HX`)_E.!"?Y6#X_^L!`*#CFOC_ZXB8``"HF0``6,X!````@/___\]!U,\`
M`'C1``#8SP``7,@```C/```4SP``],\``$RN`0#P3RWI["&?Y0':3>(DT$WB
M`#"2Y0$JC>(`@*#A'#""Y=0!G^4!4*#A._S_Z\RAG^4`0)KE!!"@X0!PH.$(
M`*#A$/C_ZP!@4.(,```*"!"@X:P!G^7(_?_KF!&?Y0$ZC>(<()/E`#"1Y0@`
MH.$#`%+A7P``&B30C>(!VHWB\(^]Z`@`H.'J]__K'+":Y0L0H.$`,*#A!0"@
MX1`PC>47^/_K$#"=Y0!04.)!```*(*"-XE"1G^4!,(/B!*!*XA0PC>4`,-7E
M``!3XPE0H`$``%?C!```"@<`H.$%$*#A4OC_ZP``4.,M```*!0"@X=#W_^L`
M(-3E`#"%X`$04^4"`%'A!@``&@%@0^4"(%/E`!#4Y0$`0.("`%'A`3!#XOC_
M_PH4,)WEX!"?Y0``@^`!`%#AQ?__R@$0H.,!*J#CS#"?Y0H`H.$`4(WE$`&-
MZ1CX_^L``*#C)?C_ZP``D.69]__K[_?_ZPH0H.$`(*#A`P"@X]/W_^L``%#C
M!P``&AOX_^L``)#EC_?_Z^7W_^L0,)#E#SH#X@()4^,)```*``"@XPL0H.'5
M]__K``!0XP!0H.'"__\:"!"@X40`G^5N_?_KI/__Z@H`H.$!$*#C@/?_ZP``
M4./P__\:"A"@X2``G^5E_?_K"@"@X0/X_^L`@*#AF/__ZK[W_^M(K@$`%,\`
M`$3.```XSP``R,\``/\/``#PS@``\$\MZ3QXG^6!W$WB1#"'XC303>(P6)_E
M`("@X0\`D^@33HWB`."5Y0)IC>+`0$3B5,"'XBSAAN437HWB#P"$Z`\`O.C8
M4$7B!>"@X0\`KN@#`)SH;,"'X@,`CN@'`)SH$ZZ-XK"@2N('`(KHW`>?Y:3[
M_^L`8%#B`@``"@`PUN4``%/CG0$`&D[^_^L`8%#BH0$`"@"@UN4``%KC"@``
M"G_W_^L&,*#A7Q"@XP`@D.6*H*#ANB"2X0@`$N,`$,,%`:#SY0``6N/W__\:
M@#>?Y8$LC>(P((+B`P"2YP`PT.4``%/C;P$`"@6@H.$#``#J!`"ZY0`PT.4`
M`%/C:0$`"H#[_^L`4%#B^/__"KG\_^L``%#C]?__"@4`H.&Q]__K`%!0XO'_
M_PH%`*#A._?_ZP!`H.$&`*#A./?_ZP``A.`!"X#B!`"`XF'W_^L$QY_E`"#@
MXP`WG^4`D)?E`1"@XPC`C>4`4(WE#&"-Y020C>4`0*#AB??_Z^`6G^4$`*#A
MP_;_Z]@&G^5>^__K*$"-Y0``4.->`0`*`%"8Y9'W_^L`$*#A!0"@X0___^L`
M4%#B5P$`"EG[_^L`$%#B-P``"@0`H.$5]__KF!:?Y9AFG^4`4*#C!8"@X0!P
MH.&,!I_EX/S_ZUCW_^L!$*#C`"#@XWPVG^40`HWH#&"-Y0@`C>4$`*#A9??_
MZP\``.J']__K`#"0Y1$`4^,1```:!X#$YTGW_^L!4(7B"B"@X0$0H.-`-I_E
M$`*-Z`Q0C>408(WE"`"-Y00`H.%4]__K!`"@X0@6G^6.]O_K`0!PXP"@H.'I
M__\*Y`6?Y000H.&]_/_K!`"@X33]_^O,A9_E`FF-XBPAEN4`,)CE*`"=Y0,`
M4N%K`0`:3=^-X@+9C>+PC[WH!0"@X>SV_^L`,%#B)#"-Y<+__PH3OHWB`##@
MXQ$@X..DL$OB`E"@XP!0C>7]]O_K)`"=Y0L0H.$&(*#CL?;_ZX%LC>*0-9_E
M,&"&X@,PUN<``%/C`@``&@$PV^5#`%/C&`$`"G0EG^4"B8WBC""(Y2(C@N(B
M)X+B(BN"XH@@@N(":8WBD""(Y50EG^6,8(;BE""(Y0)YC>)()9_E`#"@XY@@
MB.4<P(;B/"6?Y:APA^($H*#AG""(Y>@PB.6@,(CEI#"(Y2S`C>4D`)WE"Q"@
MX0(IH..+]O_K`$!0XD(``-H"Z8WBH"">Y0)9C>*$,8+@`P!2X0(9C8*D()&%
M#@"@D:0@D)7H`)7E`2""@J0N@N```%#CH#"%Y:0@A>4+@*`!$@``"D"`8.(L
MP)WE"`!4X02`H+$(@*"A``",X`L0H.$((*#AD_;_ZP+IC>+H,)[E`S"(X$``
M4^/H,([EV?__&@8`H.$$0&C@"("+X$SW_^L_`%3C#P``V@!0H.,%$(C@0""@
MXP<`H.&"]O_K0%"%X@8`H.%"]__K!#!EX#\`4^/U___*0$!$XB0SH.$!((/B
M`H.(X`-#1.`$(*#A"!"@X40PH.,L`)WE6O;_ZP()C>+H0(#E"Q"@X20`G>4"
M*:#C2/;_ZP!`4.*\___*)`"=Y7KV_^L"&8WBH%"1Y8&,C>*E(:#A/R`"X@$P
M@N(P@(CBI'"1Y0(@B.!_$.#C.`!3XPI`H.&($$+EPP``RAP`AN(#`(#@."!C
MX@`0H.,6]O_K`HF-XB?HH.$GQ*#A)1R@X24HH.$E-*#A!@"@X2=LH.'@8,CE
MX>#(Y>+`R.7C<,CEY!#(Y>4@R.7F,,CEYU#(Y0?W_^L"R8WBD`"<Y900G.4@
M:*#AF""<Y2Q@C>4A;*#AG#"<Y31@C>4A9*#A/&"-Y2)HH.%$8(WE(VR@X8S@
MG.4@7*#A3&"-Y2-DH.$D4(WE5&"-Y2!4H.&!;(WB,%"-Y1O@QN4A6*#A+LR@
MX2ZHH.$NM*#A)."=Y3A0C>4<X,;E(ER@X2S@G>4=X,;E'P#&Y3#@G>4T`)WE
M0%"-Y0*)C>(B5*#A'N#&Y2``QN4XX)WE[("(XDA0C>4\`)WE(UB@X2'@QN50
M4(WE&:#&Y1JPQN4<@(WE(@#&Y2,0QN5$X)WE0!"=Y200QN4EX,;E)R#&Y8%\
MC>)(`(WB!T"0Z"8`QN4H$,;E*2#&Y2K@QN4K,,;E&,#&Y0!0H.,8<(?B"&"@
MX0```.H%P-?G!@"@X0%0A>(!$*#C`"#@XS`RG^4`P(WE3O;_ZQ0`5>,"8(;B
M]/__&@#`H..!7(WB%,#%Y00`H.'DP9_E`1"@XP`@X.,`,I_E!)"-Y0B`C>4,
MP(WE`$"-Y3[V_^ON_O_JZ#&?Y8',C>(PP(SB`Z"<YP!0VN4``%7C!```&I?^
M_^H$H+3E`##:Y0``4^,'```*"@"@X47[_^L``%#C]___"@H`H.$]]O_K``!0
MX_/__PH`4*#AB?[_ZA'\_^L&`*#A-O;_ZR@`C>78_O_J`%"8Y:7^_^IX,9_E
M@1R-XC`0@>(#`)'G`##0Y0``4^,)```*\OG_ZP``4.,"```*)_;_ZP``4.,Z
M```:!`"ZY0`PT.4``%/C]?__&CAAG^58_O_J`C#;Y4$`4^/C_O\:`S#;Y4,`
M4^/@_O\:!##;Y4@`4^/=_O\:!3#;Y44`4^/:_O\:`##@XSD@X.,D`)WE`%"-
MY<;U_^L+$*#A)`"=Y2D@H.-Z]?_KJ,"?Y00`H.$!$*#C`"#@X\`PG^40&HWH
M\?7_ZZ'^_^H<`(;B0"!CX@,`@.``$*#C4O7_ZP8`H.%2]O_K`#"@XP+)C>+<
M,(SEJ#",Y:PPC.6P,(SEM#",Y;@PC.6\,(SEP#",Y<0PC.7(,(SES#",Y=`P
MC.74,(SEV#",Y2C__^H`8*#A$_[_ZJ7U_^M$S@``2*X!`!3/```H?___S,\`
M`-S/``#M`0``7-$``,3/``#0SP``O,X```#0```0T```7'___P$C16?^W+J8
M=E0R$/#ATL/XSP``Z,\``$!___]0?___)-```/!'+>D``*#CRO7_ZP``D.4^
M]?_K0_7_ZP$PH.,`,,#EA`.?Y8[Y_^L``%#C`@``"@`PT.4Q`%/CC0``"MO[
M_^L``*#CN_7_ZP``D.4O]?_K6!.?Y0$@H.,+,*#C"O7_ZP``4.-(8Y\%-```
M"D!CG^4,()#E[#\6Y1B`DN4!`%/C`%"@TRH``-H`4*#C`4"@XP@``.H'`*#A
MM?7_ZP``4.,B```:[#\6Y0%`A.($`%/A`5"%XAX``-H``*#CG?7_ZP``D.41
M]?_K"!"@X04@H.$`,*#C.O7_ZP"04.(3```*`#"9Y?`O%N4(H)/E!'&2YP&K
M&N(,$),5Y?__&@H`H.&,]?_K``"0Y0#U_^L`$)GE"B"@X0(PH..A]?_K`!"@
MX0<`H.&2]?_K``!0X]S__PKL/Q;E`2!#X@4`4N%0```*``"@XWOU_^L``)#E
M[_3_ZV`2G^4!(*#C!3"@X\KT_^L`0%#B#```"@``H.-Q]?_K``"0Y>7T_^L,
M,)3E."*?Y0`0D^7&]/_K##"4Y0`PD^4(,)/E`043XT<``!H``*#C9/7_ZP``
MD.78]/_K#!*?Y0$@H.,%,*#CL_3_ZP!`4.(+```*^`&?Y27Y_^L`4%#B00``
M"@``H.-6]?_K``"0Y<KT_^L,,)3E!2"@X0`0D^6K]/_K``"@XT[U_^L`<*#C
MK%&?Y0``D.7`]/_KQ?3_ZP!PP.4'`*#A1O7_ZP``D.6Z]/_K3_7_ZP!P@.64
M`9_E"_G_ZP<`4.'H#P;E+P``"H01G^5I]/_K$0!0XP``4!/PA[T(`0!PX_"'
MO0CP/Q7EZ"\5Y0`0D^4`,*#A7`&?Y0;U_^L!,-#E``!3XV___PIM___J`0!3
MXZS__]H!0*#C``"@XR?U_^L!0(3B``"0Y9KT_^L($*#A=/3_Z^P_%N4$`%/A
M]?__RJ#__^H``*#C'/7_ZP``D.60]/_K##"4Y0`0D^7/]/_KK___ZA7U_^L`
M`)#EB?3_ZPP@E.7P/Q;E`!"2Y0`@D^4)^?_KO/__ZO`/%>44_?_KZ`\%Y0PP
ME.4`,)/E"%"3Y0%;%>(,`),5"```&@4`H.$"]?_K``"0Y7;T_^L,,)3E!2"@
MX0`0D^4",*#C%O7_Z_`?%N57]/_K##"4Y?`O%N4`,)/E`&"2Y0APD^4!>Q?B
M#""3%0!0H.$)```:!P"@X>[T_^L``)#E8O3_ZPPPE.4'(*#A`!"3Y0(PH.,"
M]?_K`""@X080H.$%,*#A*`"?Y;CT_^OXS@``+-```%C.`0`TT```.-```$#0
M```XSP``%,\``.T!``!TT```1-```!!`+>D``*#CU/3_ZP``D.5(]/_K#!"?
MY0P@G^4,,)_E$$"]Z,3T_^K$T```G)D``.#0```$X"WE``"@XPS03>+&]/_K
M``"0Y3KT_^OK___K``"@X\'T_^L``)#E-?3_ZQS`G^4`X*#C##"@X100G^44
M()_E`%"-Z$/T_^L,T(WB`("]Z-#/``#LT```4,0``!PPG^4<P)_E!$`MY0,P
MC^`,0)/@##"3%P0PH`$0`+WH??3_ZA#D``!D(?__'O\OX?!'+>E0H)_E4%"?
MY0!@H.$!<*#A`H"@X</S_^M`,)_E!5!JX`,PC^!%4;#A"J"#X/"'O0@`0*#C
M!#&:YP8`H.$!0(3B!Q"@X0@@H.$S_R_A!0!4X??__SKPA[WHM/[__[C^___(
MXP```A$AX@```.H",2/B,$`MZ8%`H.&#4*#A!0`TX0(`,`$`P)01`L"5$<3*
M\!'%RO`1>0``"J1*H.&E6G3@`%!EL@8``-H%0(3@`B`@X`,P(>```"+@`1`C
MX`(@(.`#,"'@-@!5XS"`O8@"`1'C`1:@X0'&H.,A%HSA`0``"@``<.(`$.'B
M`@$3XP,VH.$C-HSA`0``"@`@<N(`,./B!0`TX5<```H!0$3B(.!UX@4``+H2
MSJ#A,@60X``0H>(3#I#@4Q6QX`8``.H@4$7B(.".X@$`4N,3SJ#A`L",(U,%
MD.##'['@`E$!X@(``%H`P'SB``#PX@`0X>(!!E'C#@``.@(&4>,&```ZH1"P
MX6``L.%LP*#A`4"$XH0JH.$!!7+C50``*@(!7..@P+`!``"PX@0:H>`%$('A
M,("]Z(S`L.$``+#@`1"AX`$&$>,!0$3B\___&@``,>,`$*`!``"@`Q$_;^$@
M,(,""S!#XB`@4^('``"J#""2X@0``-H4P(+B#"!BXA$,H.$Q$J#A!```ZA0@
M@N(@P&+2$1*@X3`<@=$0`J#1`T!4X`0:@:`%$(&A,("]J`1`X.$?0%3B#0``
MJ@Q`E.(%``#*%$"$XB`@9.(P!*#A$0*`X3$4A>$P@+WH#$!DXB`@9.(P`J#A
M$02`X040H.$P@+WH,02@X040H.$P@+WH```TXP$V(^(!%B$"`4"$`@%011*A
M___JQ,KPX<7*\!$8```*!0`TX0(`,`$#```*`,"4X0,0H`$"`*`!,("]Z`,`
M,>$`$*`3``"@$S"`O1BDRK#A`P``&H``L.$!$+'@`A&!(S"`O>@!193B`1:!
M,C"`O3@"40'B?Q2%XP\6@>,``*#C,("]Z,3*\.$#$*`1`@"@$<7*\`$!,*`1
M`""@$0%&D.$#5I(!`P`Q`0(7@1,P@+WH```PXP`0H`,>_R\!,$`MZ0%+H.,R
M0(3B`%"@XP`0H..=___J```PXP`0H`,>_R\!,$`MZ0%+H.,R0(3B`E$0X@``
M8$(`$*#CD___ZH`@L.'"$:#A81"@X0(.H.'_-!(2_P0S$PX3(1(>_R\1```R
MX_\$,Q,>_R\!,$`MZ0Y-H.,"40'B`A'!XX/__^H!()#A'O\O`3!`+>D`4*#C
M!@``Z@$@D.$>_R\!,$`MZ0)1$>(!``!:``!PX@`0X>(!2Z#C,D"$XB'+L.%<
M__\*`R"@XZS!L.$#(((2K,&PX0,@@A*L(8+@(#!BXA##H.$P`J#A$0.`X3$2
MH.$"0(3@3___Z@#`X.,"``#J`<"@XP```.H!P*#C!,`MY8'`H.',RO#A@\"@
MX<S*\!$.```*!-"-XH'`D.&#P)(!`P`Q$0(`,`$``*`#'O\O`0``<.,#`#'A
M`P!140(`4`'##Z`APP_@,0$`@.,>_R_A@<"@X<S*\.$!```:`<:0X00``!J#
MP*#AS,KPX>C__QH#QI+AYO__"@0`G>0>_R_A`,"@X0(`H.$,(*#A`<"@X0,0
MH.$,,*#A____Z@%`+>G4___K``!0XP``<$,!@+WH".`MY?C__^L!`*`#``"@
M$PCPG>0(X"WE\___ZP$`H#,``*`C"/"=Y`C@+>7N___K`0"@DP``H(,(\)WD
M".`MY>+__^L!`*"3``"@@PCPG>0(X"WEW?__ZP$`H#,``*`C"/"=Y!!`+>D0
M@+WH`0`"```````$T0``/-$``$S1``!4T0``7-$``&31``#0SP``.-$``%]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@`````"C1```PT0``R,\`
M`-#/``"(SP``C,\``!S1```8SP``)-$``-#/```(T0``$-$``-#/``!005)?
M0TQ%04X````O<')O8R]S96QF+V5X90``)7,O)7,````O<')O8R\E:2\E<P!E
M>&4`)7,E<R5S``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27U1%
M35``````4$%27T1%0E5'````4$%27T-!0TA%````4$%27U!23T=.04U%````
M`%!!4E]!4D=#`````%!!4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<`````
M4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````+@```'!A
M<BT`````+64``"TM```E<R5S)7,E<P`````E<R5S8V%C:&4M)7,E<P``)3`R
M>``````E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P````!365-4
M14T``$%21U8`````&````'!E<FP`````,````"5S.B!E>&5C=71I;VX@;V8@
M)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*`"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@
M86)O<G1I;F<@=VET:"`E:2X*````1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`'!E<FQX<VDN8P```$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"\```!5
M4T52`````%5315).04U%`````%1%35!$25(`5$U0`$,Z7%1%35``+W1M<```
M```Z````3$1?3$E"4D%265]0051(`$Q)0E!!5$@`3$E"4D%265]0051(````
M`$193$1?3$E"4D%265]0051(````(R$O=7-R+V)I;B]P97)L"@IE=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[
M(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A
M<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D
M=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE
M(#$U.0H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.
M1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ
M5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E
M($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL
M97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T
M:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I
M.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P
M9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P
M<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3
M;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D
M:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O
M;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@
M("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN
M('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L
M;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B
M>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O
M;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@
M("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@
M("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-
M4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&
M25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@
M("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@
M(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*
M("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D
M(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M
M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO
M<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ
M<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]
M('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R
M7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD
M("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)0
M05)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@
M)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES
M("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'
M5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*
M(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF
M:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@
M)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-
M4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@
M("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI
M.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC
M('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L
M97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A
M;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@
M='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@
M7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I
M.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D
M(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2
M+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F
M*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]
M("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@
M96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES
M=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@
M7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@
M("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D[
M"B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=
M>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE
M+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@
M("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H
M)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@
M("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E
M>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@
M("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O
M=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@
M("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@
M(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@
M;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE
M(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@
M("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E
M;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@
M("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U
M9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@
M96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]
M"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@
M("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@
M)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R
M96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@
M0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE
M.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@
M("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@
M("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@
M("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D
M:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F
M:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@
M("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@
M("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@
M("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L
M("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D[
M"B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA
M;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O
M<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T
M<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@
M?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![
M>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG
M"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y
M.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S
M(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A
M9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M
M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C
M;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU3
M5VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F
M:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@
M;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@
M("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@
M("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E
M)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@
M)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<
M+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*
M("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T
M87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT
M('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*)'%U:65T(#T@,"!U;FQE<W,@
M)$5.5GM005)?1$5"54=].PH*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F
M;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS
M"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO
M;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@
M("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@
M("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*
M("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("!M>2!`861D7W1O
M7VEN8SL*("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("1!4D=66S!=(#U^
M("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@
M(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@<'5S:"!`861D7W1O7VEN
M8RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*
M("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("!]"B`@("`@("`@
M96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("!U;G-H:69T($!P87)?
M87)G<RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G3R<I
M('L*("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@('T*("`@("`@("!E
M;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("1B=6YD;&4@/2`G<VET
M92<["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@
M("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@('T*("`@("`@("!E
M;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("1Q=6EE="`](#$["B`@
M("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@("`@("`@
M("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@
M;W!E;B!L;V<Z("0A(CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q
M("=4)RD@>PH@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@
M('T*"B`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("!I9B`H;7D@)&-M
M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@9&5L971E("1%3E9[
M)U!!4E]414U0)WT["B`@("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@
M("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`F>R)005(Z.D1I
M<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@("`@("`@97AI
M=#L*("`@("`@("!]"B`@("!]"@H@("`@=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC
M('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U
M="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?
M1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)
M3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*
M"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@
M("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G
M/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@
M("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@
M("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE(")2
M96%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@
M9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O
M;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@("`@("`@("1M971A(#U^(',O
M+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M
M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG
M.PH@("`@("`@('T*("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P
M=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I
M;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I
M92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D
M:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B
M4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@
M("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*
M("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/
M3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@
M("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD
M969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S
M965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X[
M"B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O
M7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D
M:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV
M>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D
M=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!
M4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%2
M7R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S
M>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@
M)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]96<[
M"B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E
M9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM[
M"B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V
M>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@
M("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D[
M"@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H
M*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@
M("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("@D
M8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#
M.PH*("`@("`@("!I9B`H)$-O;F9I9WM?9&5L:6U](&5Q("=<7"<I('L@<WM<
M7'U[+WUG(&9O<B!`:6YC('T*"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T97-T
M(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N
M+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL
M:6(O875T;W-P;&ET+FEX+@H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED
M(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@
M("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U
M;F1E<G-T86YD:6YG('=H870G<R!H87!P96YI;F<L"B`@("`@("`@(R!)(&9A
M:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O
M7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES
M("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*
M("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R
M="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE
M*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@
M("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD7WTI('L*("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PH@("`@
M("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I
M*2!["B`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L
M("0R*3L*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO
M*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&UY("1R
M968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q
M(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]
M("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S
M=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@
M)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@
M("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@
M("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF
M("AR968H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]("1F
M:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@
M(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO
M9&4H1DE,12D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*
M("`@("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@("`@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@
M("`@("`@("`@(",@1&\@;F]T(&QE="!84TQO861E<B!P:6-K('5P(&%U=&\O
M*B!F<F]M(&5N=FER;VYM96YT"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]
M?B!S+V=O=&\@*W)E=')Y("MU;FQE<W,@*RXJ+V=O=&\@<F5T<GD[+PH@("`@
M("`@("`@("`@("`@("`@(&EF(&QC*"1N86UE*2!E<2!L8R@B6%-,;V%D97(N
M<&TB*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET
M=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,
M12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H
M"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M
M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@
M("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@
M("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE
M(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&
M:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U
M8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T
M.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@
M(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E
M<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B
M8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@
M("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*
M("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@
M("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F
M:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N
M86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*
M("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE
M7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^
M<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@
M)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT
M*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U
M-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P
M87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G
M;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@
M:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@
M("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@
M("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@
M;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@
M("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN
M97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@
M(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A
M.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0
M?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*
M("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@
M>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@
M("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M
M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U[
M"B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@
M("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_
M"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]
M+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D
M"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE
M(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@
M("`@("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R
M+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U=',H
M<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E
M>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@("`@("`D;65M
M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@
M("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP
M=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*
M?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W
M('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI
M('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A
M=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I
M(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI
M.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@
M("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE
M("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN
M84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R
M:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*
M("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@
M("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@
M(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*
M("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@
M(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@
M("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E
M.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V
M>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@
M(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!3
M8V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N
M>FEP.CI"=7)S="!].PH@("`@979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.
M86UE9$-A<'1U<F4@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D
M92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS
M;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV
M(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@
M("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@
M(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W
M*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@
M("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60[
M"B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@
M>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M("`@("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@
M("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@
M("`@96QS92!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!
M345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@
M("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M)'5S97)N86UE(CL*("`@
M("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[
M4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;
M.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M
M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@
M('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U
M9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M
M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$[
M"B`@("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@
M("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B
M=68["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@
M("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[
M($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@
M("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A
M;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A
M;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@
M("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I
M;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D
M9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C
M='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@
M?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@
M(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@
M("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M
M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D[
M"@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA
M;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F
M:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD
M968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@
M;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO
M9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M
M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N
M86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD969I;F5D("1%3E9[
M4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI
M+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G
M;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.
M5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L
M("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@
M("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5]
M.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D
M9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P
M<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@("`@:68@
M*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@
M("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@
M(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C
M=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#
M=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W
M9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E
M;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*
M("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@
M("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.
M251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!4
M14U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@
M*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@
M(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@
M("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF
M(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY
M("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D
M14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@
M<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@
M("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?
M0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@
M:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L
M;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B
M0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O
M;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB
M97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U
M=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*
M9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S
M("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D
M,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,#(*
M"E]?14Y$7U\*````<&%R+G!L``"!L@&!L+"L!P````"(L@&!L+"O!P````#,
ML@&!L+"O/P````#L</]_`0```%B`_W_0__]_4('_?["PJ(!8@_]_L*P;@'"$
M_W^PL*J``(7_?P$````PBO]_L+"H@$"*_W\!````[(O_?["J!8`\CO]_G/__
M?TB0_W^@__]_Y)C_?["PKH"TG/]_L+"H@."<_W\`A`*`-)W_?P$`````````
M?)P``&"<`````````0````$````!````N@(```$```#)`@```0```-4"```!
M````X`(```$```#J`@```0```/@"```!````!0,```$```!4`P```0```)D$
M```!````N00```\```!$!0``#````!28```-````-,X``!D```"0JP$`&P``
M``0````:````E*L!`!P````$````]?[_;XR!```%````4(T```8```"`A0``
M"@```)\&```+````$````!4``````````P```-RL`0`"````B`(``!0````1
M````%P```(R5```1````;)4``!(````@````$P````@```#^__]O[)0``/__
M_V\$````\/__;_"3````````````````````````````````````````````
M``````````````````````"<JP$````````````@F```()@``""8```@F```
M()@``""8```@F```()@``""8```@F```()@``""8```@F```()@``""8```@
MF```()@``""8```@F```()@``""8```@F```()@``""8```@F```()@``""8
M```@F```()@``""8```@F```()@``""8```@F```()@``""8```@F```()@`
M`""8```@F```()@``""8```@F```()@``""8```@F```()@``""8```@F```
M()@``""8```@F```()@``""8```@F```()@``""8```@F```()@``""8```@
MF```()@``""8```@F```()@``""8```@F```()@``""8```@F```()@``""8
M```@F```()@``""8```@F```()@``""8```@F```()@``""8````````````
M`/_____H*@$`;5D``$$F````865A8FD``1P````%-51%``8$"`$)`1($%`$5
M`1<#&`$:`D=#0SH@*$=.52D@-"XT+C0@,C`Q,#`W,3,@*%)E9"!(870@-"XT
M+C0M,30I```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E
M+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N
M=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI
M=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AT86(`+D%232YE>&ED>``N
M96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI
M8P`N9V]T`"YD871A`"YB<W,`+D%232YA='1R:6)U=&5S`"YC;VUM96YT````
M```````````````````````````````````````````````````````+````
M`0````(````T@0``-`$``!,```````````````$`````````$P````<````"
M````2($``$@!```@```````````````$`````````"$````'`````@```&B!
M``!H`0``)```````````````!``````````T````]O__;P(```",@0``C`$`
M`/0#```%``````````0````$````/@````L````"````@(4``(`%``#0!P``
M!@````$````$````$````$8````#`````@```%"-``!0#0``GP8`````````
M`````0````````!.````____;P(```#PDP``\!,``/H````%``````````(`
M```"````6P```/[__V\"````[)0``.P4``"`````!@````0````$````````
M`&H````)`````@```&R5``!L%0``(`````4`````````!`````@```!S````
M"0````(```",E0``C!4``(@"```%````#`````0````(````?`````$````&
M````%)@``!08```,```````````````$`````````'<````!````!@```""8
M```@&```X`,`````````````!`````0```""`````0````8`````G````!P`
M`#0R``````````````0`````````B`````$````&````-,X``#1.```(````
M```````````$`````````(X````!`````@```#S.```\3@``M%P`````````
M````!`````````"6`````0````(```#P*@$`\*H``"0```````````````0`
M````````H0````$``'""````%"L!`!2K``!X````#0`````````$````````
M`*P````!`````@```(PK`0",JP``!```````````````!`````````"V````
M#@````,```"0JP$`D*L```0```````````````0`````````P@````\````#
M````E*L!`)2K```$```````````````$`````````,X````!`````P```)BK
M`0"8JP``!```````````````!`````````#3````!@````,```"<JP$`G*L`
M`$`!```&``````````0````(````W`````$````#````W*P!`-RL``!4`0``
M```````````$````!````.$````!`````P```#"N`0`PK@``$```````````
M````!`````````#G````"`````,```!`K@$`0*X``#00``````````````@`
M````````[`````,``'```````````$"N```G```````````````!````````
M`/P````!````,`````````!GK@``+0```````````````0````$````!````
M`P``````````````E*X```4!``````````````$``````````0```""8````
M```````,``0````PF```````````#``!````-)@```````````P``"1A`"1D
!````
